==> plantuml-1.2025.10.tar.gz: plantuml-1.2025.10/src/main/java/net/sourceforge/plantuml/skin/PragmaKey.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.skin;

public enum PragmaKey {
	
	// Temporary pragma
	SVGNEWDATA,
	SEQUENCE_MESSAGE_SPAN,
	
	// For debug
	EMULATE_NO_GRAPHVIZ_INSTALLATION,
	EMULATE_GRAPHVIZ_CRASH,
	EMULATE_GRAPHVIZ_244_ON_WINDOWS,

	ASPECT, //
	COMPACT, //
	DEFAULT_LABEL_ANGLE, //
	DEFAULT_LABEL_DISTANCE, //
	EDGE_CORNER_RADIUS, //
	GRAPH_ATTRIBUTES, //
	HORIZONTAL_LINE_BETWEEN_DIFFERENT_PACKAGE_ALLOWED, //
	KERMOR, //
	LABEL_ANGLE, //
	LABEL_DISTANCE, //
	RATIO, //
	SHOW_DEPRECATION, //
	SVG_FONT, //
	SVG_INTERACTIVE, //
	SVEK_TRACE, //
	TEOZ, //
	TEX_SYSTEM, //
	TEX_PREAMBLE, //
	USE_INTERMEDIATE_PACKAGES, //
	USE_VERTICAL_IF;

	private static String simplify(String s) {
		final StringBuilder result = new StringBuilder();

		for (char c : s.toCharArray())
			if ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z'))
				result.append(Character.toLowerCase(c));

		return result.toString();
	}

	public static PragmaKey lazyFrom(String s) {
		for (PragmaKey key : values())
			if (simplify(s).equals(simplify(key.name())))
				return key;
		return null;
	}

}

==> plantuml-1.2026.1.tar.gz: plantuml-1.2026.1/src/main/java/net/sourceforge/plantuml/skin/PragmaKey.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.skin;

public enum PragmaKey {
	
	// Temporary pragma
	SEQUENCE_MESSAGE_SPAN,
	
	// For debug
	EMULATE_NO_GRAPHVIZ_INSTALLATION,
	EMULATE_GRAPHVIZ_CRASH,
	EMULATE_GRAPHVIZ_244_ON_WINDOWS,

	ASPECT, //
	COMPACT, //
	DEFAULT_LABEL_ANGLE, //
	DEFAULT_LABEL_DISTANCE, //
	EDGE_CORNER_RADIUS, //
	GRAPH_ATTRIBUTES, //
	HORIZONTAL_LINE_BETWEEN_DIFFERENT_PACKAGE_ALLOWED, //
	KERMOR, //
	LABEL_ANGLE, //
	LABEL_DISTANCE, //
	RATIO, //
	SHOW_DEPRECATION, //
	SVG_FONT, //
	SVG_INTERACTIVE, //
	SVEK_TRACE("true"), //
	TEOZ("true"), //
	TEX_SYSTEM, //
	TEX_PREAMBLE, //
	USE_INTERMEDIATE_PACKAGES, //
	USE_VERTICAL_IF;
	
	private final String defaultValue;
	
	private PragmaKey() {
		this(null);
	}

	private PragmaKey(String defaultValue) {
		this.defaultValue = defaultValue;
	}

	public final String getDefaultValue() {
		return defaultValue;
	}


	private static String simplify(String s) {
		final StringBuilder result = new StringBuilder();

		for (char c : s.toCharArray())
			if ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z'))
				result.append(Character.toLowerCase(c));

		return result.toString();
	}

	public static PragmaKey lazyFrom(String s) {
		for (PragmaKey key : values())
			if (simplify(s).equals(simplify(key.name())))
				return key;
		return null;
	}

}
